//////////////////////////////////////////////////////////////////////////////////////////
// model by Efrem Castelnuovo and Salvatore Nistic                                     //
// code referring to the paper " Stock Market Conditions and Monetary Policy            //
// in a DSGE Model for the U.S.", Journal of Economic Dynamics and Control              //
// to replicate the results of the paper, please manipulate the code accordingly and    //
// run it with Dynare 3.0.                                                              //
//////////////////////////////////////////////////////////////////////////////////////////


// housekeeping
rand('state',100);

var r, xgap, sgap, infl, inflwage, ynat, wnat, rrnat, qnat, wgap, yhat, qhat, what, 
    diffg, diffynat, diffnu, diffa, diffr, nu, g, mup, muw, ur, endop, endow, erpr, 
    chat, // novelty of the 7 variables version!
    ygrobs, 
    inflobs, 
    ffrobs,
    rwagegrobs,
    qgrobs,
    cgrobs,
    lnobs, diffn; // latent variables + observables    
// 

parameters xi, alpha, eta, delta, hbar, thetap, thetaw, omegabar, phip, phiw, phis, phix, phir, gss, mupss, muwss, gamma, 
           rss, inflss, difflnss, rhog, rhomup, rhomuw, rhonu, rhor, rhoa, chip, chiw, rhoerpr, wnyse;
// lnss,

varexo epsa, epsg, epsr, epsmup, epsmuw, epsrpr, epsnu, epsmesp;
//      ; epsygrme, epsinflme, epsrwagegrme, epsffrme;


// fixed (i.e. not estimated) parameters
alpha = .36; // .36 as in Rabanal and Rubio-Ramirez (2005,JME)
gss = 0.18; // 0.18, Smets and Wouters (2007)
gamma = 0.0047; // ygrobs, sample mean 54q3-end=0.0047; 60q1-end=0.0047; 66q1-end=0.0040; 82q4-end=0.0058; 85q1-end=0.0051; 92q1-end=0.0058;
inflss = 0.0081; // inflobs, sample mean 54q3-end=0.0081; 60q1-end=0.0084; 66q1-end=0.92; 82q4-end=0.0055; 84q1-end = 0.0054; 85q1-end=0.0054; 92q1-end=0.0046;
rss = 0.0143; // ffrqobs, sample mean 54q3-end=0.0143; 60q1-end=0.0152; 66q1-end= 0.0162; 82q4-end=0.0138; 84q1-end = 0.0133; 85q1-end=0.0128; 92q1-end=0.0102;
difflnss = 0;


// to standardize data
//seygrobs = 0.0069; // stdev 84q1-end=0.0069;
//seqgrobs = 0.0767; // stdev 84q1-end=0.0767;
//serwagegrobs = 0.0070; // stdev 84q1-end=0.0070;
//mygrobs =  0.0052; // mean 84q1-end=0.0052;
//mqgrobs = 0.0173; // mean 84q1-end=0.0173;
//mrwagegrobs = 0.0048; // mean 84q1-end=0.0048;

// estimated parameters values [to enable dynare to compute ss; initial value for posterior max indicated below]
xi  = 0.13;
hbar = .84;
thetap = .77;
thetaw = .1;
omegabar = .37;
eta = 0.35;
phip = 1.45;
phix = .09;
phiw = 0;
phis = 0;
phir = 0.78;
delta = 1.83;
mupss = .17;
muwss = .21;
rhog = .7;
rhonu = .45;
rhoa = 0.78;
rhor = 0;
rhomup = 0.62; // .89, SW '07
rhomuw = 0.96; // .96, SW '07   
chip = 0.66; // .69, SW '07
chiw = 0.6; // .84, SW '07
rhoerpr = .95;
wnyse = .5;
gamma1 = .005;

model(linear); 

// convolutions
# h = hbar/(1+gamma);
# N = ((1-alpha)*(1+gss))/((1-alpha)*(1+gss)+delta*(1-h)*(1+mupss)*(1+muwss));
# varphi = N/(1-N); 
//# bigomegaoverC = ( sigma*aleph-(1-h)*(1-beta)+sqrt( (sigma*aleph-(1-h)*(1-beta))^2+4*sigma*(1-h)*aleph ) )/(2*sigma); // without rss
# bigomegaoverC = ( (1+rss)*(1+gss)*(alpha+mupss) ) / ( ((1+rss)-(1+inflss)*(1+gamma))*(1+mupss) ); // with rss 
# denbetaSS = ((1-xi)*(1+rss)*(1-h))/((1+inflss)*(1+gamma))+ xi*(1-xi)*bigomegaoverC;
# beta = denbetaSS^(-1)*((1-h)*(1-xi)+xi*bigomegaoverC);
# psi = ((xi*(1-beta*(1-xi)))/(1-xi))*bigomegaoverC;
# psinu = (psi*(beta*(1-xi)*rhonu))/((1+psi-h)*(1-beta*(1-xi)*rhonu));
# bigtheta = (1-h)/(1+psi-h);
# betawiggle = beta*bigtheta;
//# rhowiggle = -log(betawiggle);
# bigphix = ((1-betawiggle)*mupss)/(alpha+mupss);
# bigphiw = ((1-betawiggle)*(1-alpha))/(alpha+mupss);
# lambdap = (mupss*(1-thetap)*(1-betawiggle*thetap)*(1-alpha)) / (thetap*(mupss+alpha));
# lambdaw = (muwss*(1-thetaw)*(1-betawiggle*thetaw)) / (thetaw*(mupss+varphi*(1+muwss)));
# kp = lambdap*alpha/(1-alpha);
# kw = lambdaw*(1/(1-h)+varphi/(1-alpha)); // amended on August 12 2008
# up = lambdap*(mup-mupss); 
# uw = lambdaw*(muw-muwss);


// AR(1) processes
diffa = rhoa*diffa(-1)+epsa;
endop = epsmup;
endow = epsmuw;
g = rhog*g(-1) + epsg;
nu = rhonu*nu(-1) + epsnu;
ur = rhor*ur(-1) + epsr;
mup = (1-rhomup)*mupss+rhomup*mup(-1)+endop-chip*endop(-1);
muw = (1-rhomuw)*muwss+rhomuw*muw(-1)+endow-chiw*endow(-1);
erpr = rhoerpr*erpr(-1)+epsrpr;


// first differences
diffg = g-g(-1);
diffynat = ynat-ynat(-1);
diffnu = nu-nu(-1);
diffr = r-r(-1);


// natural economy (flex prices - flex wages)

   ynat = h*((1-alpha)/(1-h*alpha+(1-h)*varphi))*ynat(-1) + ((1-alpha)/(1-h*alpha+(1-h)*varphi))*(g-h*g(-1)-h*diffa); // amended by Efrem on August 12 2008 
   wnat = h*((1-alpha)/(1-h*alpha+(1-h)*varphi))*wnat(-1) - (alpha/(1-h*alpha+(1-h)*varphi))*(g-h*g(-1)-h*diffa); // amended by Efrem on August 12 2008
   rrnat = (1/(1-h))*(diffynat(+1)-diffg(+1)+diffa(+1)-diffnu(+1)) + (h/(1-h))*(diffnu(+1)-diffynat+diffg-diffa) +
           + (psi/(1-h))*qnat - (psi/(1-h)^2)*(ynat-g-h*ynat(-1)+h*g(-1)+h*diffa) - ( (psinu*(1+psi-h)+psi)/(1-h) )*diffnu(+1);
   qnat = betawiggle*qnat(+1) + (1-betawiggle)*ynat(+1) - rrnat + diffa(+1);

// sticky price - wage economy , structural model
    
   //r = rss + (1-phir)*(phip*infl + phiw*inflwage + phis*sgap + phix*xgap)+phir*r(-1) + ur; 
   r = (1-phir)*(phip*infl + phiw*inflwage + phis*sgap + phix*xgap)+phir*r(-1) + ur; 
   xgap = (1+bigtheta*h)^(-1) * ( h*xgap(-1) + bigtheta*xgap(+1) + psi*bigtheta*sgap - (1-h)*bigtheta*(r-infl(+1)-rrnat) );
   sgap =  betawiggle*sgap(+1) + bigphix*xgap(+1) - bigphiw*wgap(+1) - (r-infl(+1)-rrnat) + erpr ;
   infl = (1+betawiggle*omegabar)^(-1) * ( omegabar*infl(-1) + betawiggle*infl(+1) + lambdap*wgap + kp*xgap + up ) ;
   inflwage = eta*(infl(-1)+diffa(-1)) + betawiggle*(inflwage(+1)-eta*(infl+diffa)) + kw*xgap - (h/(1-h))*lambdaw*xgap(-1) - lambdaw*wgap + uw; // amended by Efrem on August 12 2008
   wgap = wgap(-1) + inflwage - infl + (wnat-wnat(-1));

// computation gaps
yhat = xgap + ynat;
qhat = sgap + qnat;
what = wgap + wnat;

// additional constraints
yhat = chat + g; // consumption
yhat-yhat(-1)=(1-alpha)*diffn;

//yhat = (1-alpha)*n;

// measurement equations
ygrobs = gamma+yhat-yhat(-1)+diffa; // gamma is the net growth rate of the tech level 
//qgrobs  =  (seqgrobs/seygrobs) * ( -mqgrobs*(1-seygrobs/seqgrobs) + gamma+qhat-qhat(-1)+diffa + epsmesp ) ; 
//rwagegrobs = (serwagegrobs/seygrobs) * ( -mrwagegrobs*(1-seygrobs/serwagegrobs) + gamma+what-what(-1)+diffa ); 
qgrobs  =  gamma+qhat-qhat(-1)+diffa + epsmesp; 
//qgrobs  =  gamma+qhat-qhat(-1)+diffa ;
//qgrnyseobs = gamma+wnyse*(qhat-qhat(-1)+diffa) + epsmespnyse; 
rwagegrobs = gamma+what-what(-1)+diffa ; 
inflobs = inflss + infl;
ffrobs = rss + r ;
cgrobs = gamma+chat-chat(-1)+diffa; // consumption growth 
//hoursgrobs = difflnss + diffn; // hours, growth
lnobs-lnobs(-1) = diffn; // to relate growth rate of hours 

end; 

steady(solve_algo=3); check; // to check SS, uniqueness, and so on 

//shocks;
//var epsa; stderr .0036;
//var epsg; stderr .0054; 
//var epsnu; stderr .0091;
//var epsmup; stderr .1992;
//var epsmuw; stderr .8366;
//var epsr; stderr .0016;
//var epsrpr; stderr .0042;
//var epsmesp; stderr .0675;
//end;


estimated_params;
// PARAM NAME, PRIOR_SHAPE, PRIOR_P1, PRIOR_P2, PRIOR_P3, PRIOR_P4
// PRIOR_SHAPE: BETA_PDF, GAMMA_PDF, NORMAL_PDF, INV_GAMMA_PDF

 
xi, .05, 0, 1, UNIFORM_PDF, .5, .28;
hbar, .85, BETA_PDF, .8, .05; // habit formation 
thetap, .71, BETA_PDF, .75, .05; // calvo parameter, price setting
thetaw, .53, BETA_PDF, .75, .05; // calvo parameter, wage setting
omegabar, .14, BETA_PDF, .5, .15; // price indexation
eta, .42, BETA_PDF, .5, .15; // wage indexation
phip, 1.5, GAMMA_PDF, 1, .25; // TR price inflation
phix, .02, GAMMA_PDF, .5, .25; // TR output gap
phis, .06, NORMAL_PDF, 0, .25; // TR stock price gap
phir, .67, BETA_PDF, .7, .1; // TR IRS
//alpha, .36, BETA_PDF, .35, .1; // labor share 
delta, 0.35, GAMMA_PDF, 1.4, 1; // relative preference over leisure in the representative agent's felicity function
mupss, .12, GAMMA_PDF, .2, .05; // price mark up SS
muwss, .25, GAMMA_PDF, .2, .05; // wage mark up SS
rhog, .97, BETA_PDF, .5, .2 ;// .5, .1, Smets and Wouters (2007)
rhonu, .14, BETA_PDF, .5, .2; // .5, .1, Smets and Wouters (2007)
rhoa, .43, BETA_PDF, .5, .2; // .5, .1, Smets and Wouters (2007)
rhor, .22, BETA_PDF, .5, .2; // .5, .1, Smets and Wouters (2007)
rhomup, .87, BETA_PDF, .5, .2; // .5, .1, Smets and Wouters (2007)
//rhomuw, .96, 0, .99, BETA_PDF, .5, .2; // .5, .1, Smets and Wouters (2007)
chip, .66, BETA_PDF, .6, .15; // .5, .1, Smets and Wouters (2007)
chiw, .78, BETA_PDF, .6, .15; // .5, .1, Smets and Wouters (2007)
//gamma, .005, NORMAL_PDF, .005, .005;
//inflss, .0081, NORMAL_PDF, .0081, .00081;
//rss, .0143, NORMAL_PDF, .0143, .00143;
rhoerpr, .95, BETA_PDF, .5, .2; // autoregressive parameter for the stock price gap risk premium 

// exogenous processes 
stderr epsa, .0109, INV_GAMMA_PDF,0.01,2; // 0.01, 2, Smets and Wouters (2007)
stderr epsg, .0097, INV_GAMMA_PDF,0.01,2; // 0.01, 2, Smets and Wouters (2007)
stderr epsnu,.0340,  INV_GAMMA_PDF,0.01,2; // 0.01, 2, Smets and Wouters (2007)
stderr epsr, .0033, INV_GAMMA_PDF,0.01,2; // 0.01, 2, Smets and Wouters (2007)
stderr epsmup, .12, INV_GAMMA_PDF,0.01,2; // 0.01, 2, Smets and Wouters (2007)
stderr epsmuw, .50, INV_GAMMA_PDF,0.01,2; // 0.01, 2, Smets and Wouters (2007)
stderr epsrpr, .0045, INV_GAMMA_PDF,0.01,2; //  risk premium
stderr epsmesp, .0594, INV_GAMMA_PDF,0.01,2; // qgrobs measurement error 
end; 


// database
// data_nfbsop_54q307q2.m, obs #1=54q3, #23=60q1, #47=66q1, #114=82q4, #119=84q1, #123=85q1, #133=87Q3, #151=92q1 [variables: ygrobs, qgrobs, inflobs, inflwageobs, ffrobs, rwagegrobs, non farm, ygr and qgr per capita]
//varobs inflobs ffrobs ygrobs rwagegrobs qgrobs cgrobs lnobs;

// updated dataset: data_cn09.m, sample: 1954:III-2009:I
varobs inflobs ffrobs ygrobs rwagegrobs qgrobs cgrobs lnobs;

estimation(datafile=data_nfbsop_54q307q2, first_obs=1, prefilter=0,mode_check,mh_replic=0); 
//MH + Bayesian IRFs, just with Dynare 4 - Dynare 3 takes ages to compute Bayesian IRFs
//estimation(datafile=data_nfbsop_54q307q2, first_obs=1 ,prefilter=0,mode_compute=0,mode_file=cn_fsample_mode,lik_init=2,conf_sig=0.90,bayesian_irf,smoother,mh_nblocks=2,mh_jscale=0.25,mh_drop=0.5,mh_replic=500000);
//MH with Dynare 3
//estimation(datafile=data_nfbsop_54q307q2,first_obs=1,prefilter=0,mode_compute=0,mode_file=cn_amend_7obs_mode,lik_init=1,presample=0,conf_sig=0.90,mh_nblocks=1,smoother,mh_jscale=0.2,mh_drop=0.5,mh_replic=40000);


// Generate IRfunctions and Moments of the variables of interest
//stoch_simul r infl inflwage xgap sgap qhat qnat chat inflobs ffrobs ygrobs rwagegrobs qgrobs cgrobs diffn;
//vardecdyn3;
