function [residual, g1, g2, g3] = cn_amend_7obs_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(35, 1);
h__ = params(5)/(1+params(17));
N__ = (1-params(2))*(1+params(14))/((1-params(2))*(1+params(14))+params(4)*(1-h__)*(1+params(15))*(1+params(16)));
varphi__ = N__/(1-N__);
bigomegaoverC__ = (1+params(14))*(1+params(18))*(params(2)+params(15))/((1+params(15))*(1+params(18)-(1+params(17))*(1+params(19))));
denbetaSS__ = (1-h__)*(1+params(18))*(1-params(1))/((1+params(17))*(1+params(19)))+params(1)*(1-params(1))*bigomegaoverC__;
beta__ = denbetaSS__^(-1)*((1-h__)*(1-params(1))+params(1)*bigomegaoverC__);
psi__ = bigomegaoverC__*params(1)*(1-(1-params(1))*beta__)/(1-params(1));
psinu__ = psi__*(1-params(1))*beta__*params(24)/((1+psi__-h__)*(1-(1-params(1))*beta__*params(24)));
bigtheta__ = (1-h__)/(1+psi__-h__);
betawiggle__ = beta__*bigtheta__;
bigphix__ = params(15)*(1-betawiggle__)/(params(2)+params(15));
bigphiw__ = (1-params(2))*(1-betawiggle__)/(params(2)+params(15));
lambdap__ = (1-params(2))*params(15)*(1-params(6))*(1-betawiggle__*params(6))/((params(2)+params(15))*params(6));
lambdaw__ = params(16)*(1-params(7))*(1-betawiggle__*params(7))/(params(7)*(params(15)+(1+params(16))*varphi__));
kp__ = params(2)*lambdap__/(1-params(2));
kw__ = lambdaw__*(1/(1-h__)+varphi__/(1-params(2)));
up__ = lambdap__*(y(41)-params(15));
uw__ = lambdaw__*(y(42)-params(16));
T200 = (1-params(2))/(1-params(2)*h__+(1-h__)*varphi__);
T201 = h__*T200;
T213 = params(2)/(1-params(2)*h__+(1-h__)*varphi__);
T226 = h__/(1-h__);
T237 = psi__/(1-h__)^2;
T284 = (1+h__*bigtheta__)^(-1);
T316 = (1+betawiggle__*params(8))^(-1);
lhs =y(37);
rhs =params(26)*y(10)+x(it_, 1);
residual(1)= lhs-rhs;
lhs =y(44);
rhs =x(it_, 4);
residual(2)= lhs-rhs;
lhs =y(45);
rhs =x(it_, 5);
residual(3)= lhs-rhs;
lhs =y(40);
rhs =params(21)*y(12)+x(it_, 2);
residual(4)= lhs-rhs;
lhs =y(39);
rhs =params(24)*y(11)+x(it_, 7);
residual(5)= lhs-rhs;
lhs =y(43);
rhs =params(25)*y(15)+x(it_, 3);
residual(6)= lhs-rhs;
lhs =y(41);
rhs =y(44)+params(15)*(1-params(22))+params(22)*y(13)-params(27)*y(16);
residual(7)= lhs-rhs;
lhs =y(42);
rhs =y(45)+params(16)*(1-params(23))+params(23)*y(14)-params(28)*y(17);
residual(8)= lhs-rhs;
lhs =y(46);
rhs =params(29)*y(18)+x(it_, 6);
residual(9)= lhs-rhs;
lhs =y(34);
rhs =y(40)-y(12);
residual(10)= lhs-rhs;
lhs =y(35);
rhs =y(26)-y(4);
residual(11)= lhs-rhs;
lhs =y(36);
rhs =y(39)-y(11);
residual(12)= lhs-rhs;
lhs =y(38);
rhs =y(21)-y(1);
residual(13)= lhs-rhs;
lhs =y(26);
rhs =y(4)*T201+T200*(y(40)-h__*y(12)-h__*y(37));
residual(14)= lhs-rhs;
lhs =y(27);
rhs =T201*y(5)-(y(40)-h__*y(12)-h__*y(37))*T213;
residual(15)= lhs-rhs;
lhs =y(28);
rhs =1/(1-h__)*(y(64)-y(63)+y(66)-y(65))+T226*(y(34)+y(65)-y(35)-y(37))+psi__/(1-h__)*y(29)-T237*(h__*y(37)+h__*y(12)+y(26)-y(40)-h__*y(4))-y(65)*(psi__+(1+psi__-h__)*psinu__)/(1-h__);
residual(16)= lhs-rhs;
lhs =y(29);
rhs =y(66)+betawiggle__*y(61)+(1-betawiggle__)*y(60)-y(28);
residual(17)= lhs-rhs;
lhs =y(21);
rhs =y(43)+(1-params(13))*(params(9)*y(24)+params(10)*y(25)+params(11)*y(23)+params(12)*y(22))+y(1)*params(13);
residual(18)= lhs-rhs;
lhs =y(22);
rhs =T284*(h__*y(2)+bigtheta__*y(56)+y(23)*psi__*bigtheta__-(1-h__)*bigtheta__*(y(21)-y(58)-y(28)));
residual(19)= lhs-rhs;
lhs =y(23);
rhs =y(46)+betawiggle__*y(57)+y(56)*bigphix__-bigphiw__*y(62)-(y(21)-y(58)-y(28));
residual(20)= lhs-rhs;
lhs =y(24);
rhs =T316*(params(8)*y(3)+betawiggle__*y(58)+lambdap__*y(30)+y(22)*kp__+up__);
residual(21)= lhs-rhs;
lhs =y(25);
rhs =params(3)*(y(10)+y(3))+betawiggle__*(y(59)-params(3)*(y(37)+y(24)))+y(22)*kw__-y(2)*lambdaw__*T226-lambdaw__*y(30)+uw__;
residual(22)= lhs-rhs;
lhs =y(30);
rhs =y(25)+y(6)-y(24)+y(27)-y(5);
residual(23)= lhs-rhs;
lhs =y(31);
rhs =y(26)+y(22);
residual(24)= lhs-rhs;
lhs =y(32);
rhs =y(29)+y(23);
residual(25)= lhs-rhs;
lhs =y(33);
rhs =y(27)+y(30);
residual(26)= lhs-rhs;
lhs =y(31);
rhs =y(40)+y(47);
residual(27)= lhs-rhs;
lhs =y(31)-y(7);
rhs =(1-params(2))*y(55);
residual(28)= lhs-rhs;
lhs =y(48);
rhs =y(37)+params(17)+y(31)-y(7);
residual(29)= lhs-rhs;
lhs =y(52);
rhs =y(37)+params(17)+y(32)-y(8)+x(it_, 8);
residual(30)= lhs-rhs;
lhs =y(51);
rhs =y(37)+params(17)+y(33)-y(9);
residual(31)= lhs-rhs;
lhs =y(49);
rhs =params(19)+y(24);
residual(32)= lhs-rhs;
lhs =y(50);
rhs =params(18)+y(21);
residual(33)= lhs-rhs;
lhs =y(53);
rhs =y(37)+params(17)+y(47)-y(19);
residual(34)= lhs-rhs;
lhs =y(54)-y(20);
rhs =y(55);
residual(35)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(35, 74);

  %
  % Jacobian matrix
  %

  g1(1,10)=(-params(26));
  g1(1,37)=1;
  g1(1,67)=(-1);
  g1(2,44)=1;
  g1(2,70)=(-1);
  g1(3,45)=1;
  g1(3,71)=(-1);
  g1(4,12)=(-params(21));
  g1(4,40)=1;
  g1(4,68)=(-1);
  g1(5,11)=(-params(24));
  g1(5,39)=1;
  g1(5,73)=(-1);
  g1(6,15)=(-params(25));
  g1(6,43)=1;
  g1(6,69)=(-1);
  g1(7,13)=(-params(22));
  g1(7,41)=1;
  g1(7,16)=params(27);
  g1(7,44)=(-1);
  g1(8,14)=(-params(23));
  g1(8,42)=1;
  g1(8,17)=params(28);
  g1(8,45)=(-1);
  g1(9,18)=(-params(29));
  g1(9,46)=1;
  g1(9,72)=(-1);
  g1(10,34)=1;
  g1(10,12)=1;
  g1(10,40)=(-1);
  g1(11,4)=1;
  g1(11,26)=(-1);
  g1(11,35)=1;
  g1(12,36)=1;
  g1(12,11)=1;
  g1(12,39)=(-1);
  g1(13,1)=1;
  g1(13,21)=(-1);
  g1(13,38)=1;
  g1(14,4)=(-T201);
  g1(14,26)=1;
  g1(14,37)=(-(T200*(-h__)));
  g1(14,12)=(-(T200*(-h__)));
  g1(14,40)=(-T200);
  g1(15,5)=(-T201);
  g1(15,27)=1;
  g1(15,37)=T213*(-h__);
  g1(15,12)=T213*(-h__);
  g1(15,40)=T213;
  g1(16,4)=T237*(-h__);
  g1(16,26)=T237;
  g1(16,28)=1;
  g1(16,29)=(-(psi__/(1-h__)));
  g1(16,34)=(-T226);
  g1(16,63)=1/(1-h__);
  g1(16,35)=T226;
  g1(16,64)=(-(1/(1-h__)));
  g1(16,65)=(-(T226+(-(1/(1-h__)))-(psi__+(1+psi__-h__)*psinu__)/(1-h__)));
  g1(16,37)=(-((-T226)-h__*T237));
  g1(16,66)=(-(1/(1-h__)));
  g1(16,12)=h__*T237;
  g1(16,40)=(-T237);
  g1(17,60)=(-(1-betawiggle__));
  g1(17,28)=1;
  g1(17,29)=1;
  g1(17,61)=(-betawiggle__);
  g1(17,66)=(-1);
  g1(18,1)=(-params(13));
  g1(18,21)=1;
  g1(18,22)=(-((1-params(13))*params(12)));
  g1(18,23)=(-((1-params(13))*params(11)));
  g1(18,24)=(-((1-params(13))*params(9)));
  g1(18,25)=(-((1-params(13))*params(10)));
  g1(18,43)=(-1);
  g1(19,21)=(-(T284*(-((1-h__)*bigtheta__))));
  g1(19,2)=(-(h__*T284));
  g1(19,22)=1;
  g1(19,56)=(-(bigtheta__*T284));
  g1(19,23)=(-(T284*psi__*bigtheta__));
  g1(19,58)=(-(T284*(1-h__)*bigtheta__));
  g1(19,28)=(-(T284*(1-h__)*bigtheta__));
  g1(20,21)=1;
  g1(20,56)=(-bigphix__);
  g1(20,23)=1;
  g1(20,57)=(-betawiggle__);
  g1(20,58)=(-1);
  g1(20,28)=(-1);
  g1(20,62)=bigphiw__;
  g1(20,46)=(-1);
  g1(21,22)=(-(T316*kp__));
  g1(21,3)=(-(params(8)*T316));
  g1(21,24)=1;
  g1(21,58)=(-(betawiggle__*T316));
  g1(21,30)=(-(lambdap__*T316));
  g1(21,41)=(-(lambdap__*T316));
  g1(22,2)=lambdaw__*T226;
  g1(22,22)=(-kw__);
  g1(22,3)=(-params(3));
  g1(22,24)=(-(betawiggle__*(-params(3))));
  g1(22,25)=1;
  g1(22,59)=(-betawiggle__);
  g1(22,30)=lambdaw__;
  g1(22,10)=(-params(3));
  g1(22,37)=(-(betawiggle__*(-params(3))));
  g1(22,42)=(-lambdaw__);
  g1(23,24)=1;
  g1(23,25)=(-1);
  g1(23,5)=1;
  g1(23,27)=(-1);
  g1(23,6)=(-1);
  g1(23,30)=1;
  g1(24,22)=(-1);
  g1(24,26)=(-1);
  g1(24,31)=1;
  g1(25,23)=(-1);
  g1(25,29)=(-1);
  g1(25,32)=1;
  g1(26,27)=(-1);
  g1(26,30)=(-1);
  g1(26,33)=1;
  g1(27,31)=1;
  g1(27,40)=(-1);
  g1(27,47)=(-1);
  g1(28,7)=(-1);
  g1(28,31)=1;
  g1(28,55)=(-(1-params(2)));
  g1(29,7)=1;
  g1(29,31)=(-1);
  g1(29,37)=(-1);
  g1(29,48)=1;
  g1(30,8)=1;
  g1(30,32)=(-1);
  g1(30,37)=(-1);
  g1(30,52)=1;
  g1(30,74)=(-1);
  g1(31,9)=1;
  g1(31,33)=(-1);
  g1(31,37)=(-1);
  g1(31,51)=1;
  g1(32,24)=(-1);
  g1(32,49)=1;
  g1(33,21)=(-1);
  g1(33,50)=1;
  g1(34,37)=(-1);
  g1(34,19)=1;
  g1(34,47)=(-1);
  g1(34,53)=1;
  g1(35,20)=(-1);
  g1(35,54)=1;
  g1(35,55)=(-1);
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],35,5476);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],35,405224);
end
end
