function [residual, g1, g2] = cn_amend_7obs_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                     columns: variables in declaration order
%                                                     rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 35, 1);

%
% Model equations
%

h__ = params(5)/(1+params(17));
N__ = (1-params(2))*(1+params(14))/((1-params(2))*(1+params(14))+params(4)*(1-h__)*(1+params(15))*(1+params(16)));
varphi__ = N__/(1-N__);
bigomegaoverC__ = (1+params(14))*(1+params(18))*(params(2)+params(15))/((1+params(15))*(1+params(18)-(1+params(17))*(1+params(19))));
denbetaSS__ = (1-h__)*(1+params(18))*(1-params(1))/((1+params(17))*(1+params(19)))+params(1)*(1-params(1))*bigomegaoverC__;
beta__ = denbetaSS__^(-1)*((1-h__)*(1-params(1))+params(1)*bigomegaoverC__);
psi__ = bigomegaoverC__*params(1)*(1-(1-params(1))*beta__)/(1-params(1));
psinu__ = psi__*(1-params(1))*beta__*params(24)/((1+psi__-h__)*(1-(1-params(1))*beta__*params(24)));
bigtheta__ = (1-h__)/(1+psi__-h__);
betawiggle__ = beta__*bigtheta__;
bigphix__ = params(15)*(1-betawiggle__)/(params(2)+params(15));
bigphiw__ = (1-params(2))*(1-betawiggle__)/(params(2)+params(15));
lambdap__ = (1-params(2))*params(15)*(1-params(6))*(1-betawiggle__*params(6))/((params(2)+params(15))*params(6));
lambdaw__ = params(16)*(1-params(7))*(1-betawiggle__*params(7))/(params(7)*(params(15)+(1+params(16))*varphi__));
kp__ = params(2)*lambdap__/(1-params(2));
kw__ = lambdaw__*(1/(1-h__)+varphi__/(1-params(2)));
up__ = lambdap__*(y(21)-params(15));
uw__ = lambdaw__*(y(22)-params(16));
T185 = (1-params(2))/(1-params(2)*h__+(1-h__)*varphi__);
T186 = h__*T185;
T197 = params(2)/(1-params(2)*h__+(1-h__)*varphi__);
T206 = h__/(1-h__);
T217 = psi__/(1-h__)^2;
T262 = (1+h__*bigtheta__)^(-1);
T290 = (1+betawiggle__*params(8))^(-1);
lhs =y(17);
rhs =y(17)*params(26)+x(1);
residual(1)= lhs-rhs;
lhs =y(24);
rhs =x(4);
residual(2)= lhs-rhs;
lhs =y(25);
rhs =x(5);
residual(3)= lhs-rhs;
lhs =y(20);
rhs =y(20)*params(21)+x(2);
residual(4)= lhs-rhs;
lhs =y(19);
rhs =params(24)*y(19)+x(7);
residual(5)= lhs-rhs;
lhs =y(23);
rhs =y(23)*params(25)+x(3);
residual(6)= lhs-rhs;
lhs =y(21);
rhs =y(24)+params(15)*(1-params(22))+y(21)*params(22)-y(24)*params(27);
residual(7)= lhs-rhs;
lhs =y(22);
rhs =y(25)+params(16)*(1-params(23))+y(22)*params(23)-y(25)*params(28);
residual(8)= lhs-rhs;
lhs =y(26);
rhs =y(26)*params(29)+x(6);
residual(9)= lhs-rhs;
residual(10) = y(14);
residual(11) = y(15);
residual(12) = y(16);
residual(13) = y(18);
lhs =y(6);
rhs =y(6)*T186+T185*(y(20)-h__*y(20)-h__*y(17));
residual(14)= lhs-rhs;
lhs =y(7);
rhs =T186*y(7)-(y(20)-h__*y(20)-h__*y(17))*T197;
residual(15)= lhs-rhs;
lhs =y(8);
rhs =1/(1-h__)*(y(17)+y(15)-y(14)-y(16))+T206*(y(14)+y(16)-y(15)-y(17))+psi__/(1-h__)*y(9)-T217*(h__*y(17)+h__*y(20)+y(6)-y(20)-h__*y(6))-y(16)*(psi__+(1+psi__-h__)*psinu__)/(1-h__);
residual(16)= lhs-rhs;
lhs =y(9);
rhs =y(17)+betawiggle__*y(9)+(1-betawiggle__)*y(6)-y(8);
residual(17)= lhs-rhs;
lhs =y(1);
rhs =y(23)+(1-params(13))*(params(9)*y(4)+params(10)*y(5)+params(11)*y(3)+params(12)*y(2))+y(1)*params(13);
residual(18)= lhs-rhs;
lhs =y(2);
rhs =T262*(h__*y(2)+bigtheta__*y(2)+y(3)*psi__*bigtheta__-(1-h__)*bigtheta__*(y(1)-y(4)-y(8)));
residual(19)= lhs-rhs;
lhs =y(3);
rhs =y(26)+betawiggle__*y(3)+y(2)*bigphix__-bigphiw__*y(10)-(y(1)-y(4)-y(8));
residual(20)= lhs-rhs;
lhs =y(4);
rhs =T290*(y(4)*params(8)+betawiggle__*y(4)+lambdap__*y(10)+y(2)*kp__+up__);
residual(21)= lhs-rhs;
lhs =y(5);
rhs =params(3)*(y(17)+y(4))+betawiggle__*(y(5)-params(3)*(y(17)+y(4)))+y(2)*kw__-y(2)*lambdaw__*T206-lambdaw__*y(10)+uw__;
residual(22)= lhs-rhs;
lhs =y(10);
rhs =y(5)+y(10)-y(4);
residual(23)= lhs-rhs;
lhs =y(11);
rhs =y(6)+y(2);
residual(24)= lhs-rhs;
lhs =y(12);
rhs =y(9)+y(3);
residual(25)= lhs-rhs;
lhs =y(13);
rhs =y(7)+y(10);
residual(26)= lhs-rhs;
lhs =y(11);
rhs =y(20)+y(27);
residual(27)= lhs-rhs;
lhs =0;
rhs =(1-params(2))*y(35);
residual(28)= lhs-rhs;
lhs =y(28);
rhs =y(17)+params(17)+y(11)-y(11);
residual(29)= lhs-rhs;
lhs =y(32);
rhs =y(17)+params(17)+y(12)-y(12)+x(8);
residual(30)= lhs-rhs;
lhs =y(31);
rhs =y(17)+params(17)+y(13)-y(13);
residual(31)= lhs-rhs;
lhs =y(29);
rhs =params(19)+y(4);
residual(32)= lhs-rhs;
lhs =y(30);
rhs =params(18)+y(1);
residual(33)= lhs-rhs;
lhs =y(33);
rhs =y(17)+params(17)+y(27)-y(27);
residual(34)= lhs-rhs;
lhs =0;
rhs =y(35);
residual(35)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(35, 35);

  %
  % Jacobian matrix
  %

  g1(1,17)=1-params(26);
  g1(2,24)=1;
  g1(3,25)=1;
  g1(4,20)=1-params(21);
  g1(5,19)=1-params(24);
  g1(6,23)=1-params(25);
  g1(7,21)=1-params(22);
  g1(7,24)=(-(1-params(27)));
  g1(8,22)=1-params(23);
  g1(8,25)=(-(1-params(28)));
  g1(9,26)=1-params(29);
  g1(10,14)=1;
  g1(11,15)=1;
  g1(12,16)=1;
  g1(13,18)=1;
  g1(14,6)=1-T186;
  g1(14,17)=(-(T185*(-h__)));
  g1(14,20)=(-((1-h__)*T185));
  g1(15,7)=1-T186;
  g1(15,17)=T197*(-h__);
  g1(15,20)=(1-h__)*T197;
  g1(16,6)=(1-h__)*T217;
  g1(16,8)=1;
  g1(16,9)=(-(psi__/(1-h__)));
  g1(16,14)=(-(T206+(-(1/(1-h__)))));
  g1(16,15)=(-(1/(1-h__)-T206));
  g1(16,16)=(-(T206+(-(1/(1-h__)))-(psi__+(1+psi__-h__)*psinu__)/(1-h__)));
  g1(16,17)=(-(1/(1-h__)-T206-h__*T217));
  g1(16,20)=T217*(h__-1);
  g1(17,6)=(-(1-betawiggle__));
  g1(17,8)=1;
  g1(17,9)=1-betawiggle__;
  g1(17,17)=(-1);
  g1(18,1)=1-params(13);
  g1(18,2)=(-((1-params(13))*params(12)));
  g1(18,3)=(-((1-params(13))*params(11)));
  g1(18,4)=(-((1-params(13))*params(9)));
  g1(18,5)=(-((1-params(13))*params(10)));
  g1(18,23)=(-1);
  g1(19,1)=(-(T262*(-((1-h__)*bigtheta__))));
  g1(19,2)=1-T262*(h__+bigtheta__);
  g1(19,3)=(-(T262*psi__*bigtheta__));
  g1(19,4)=(-(T262*(1-h__)*bigtheta__));
  g1(19,8)=(-(T262*(1-h__)*bigtheta__));
  g1(20,1)=1;
  g1(20,2)=(-bigphix__);
  g1(20,3)=1-betawiggle__;
  g1(20,4)=(-1);
  g1(20,8)=(-1);
  g1(20,10)=bigphiw__;
  g1(20,26)=(-1);
  g1(21,2)=(-(T290*kp__));
  g1(21,4)=1-T290*(betawiggle__+params(8));
  g1(21,10)=(-(lambdap__*T290));
  g1(21,21)=(-(lambdap__*T290));
  g1(22,2)=(-(kw__-lambdaw__*T206));
  g1(22,4)=(-(params(3)+betawiggle__*(-params(3))));
  g1(22,5)=1-betawiggle__;
  g1(22,10)=lambdaw__;
  g1(22,17)=(-(params(3)+betawiggle__*(-params(3))));
  g1(22,22)=(-lambdaw__);
  g1(23,4)=1;
  g1(23,5)=(-1);
  g1(24,2)=(-1);
  g1(24,6)=(-1);
  g1(24,11)=1;
  g1(25,3)=(-1);
  g1(25,9)=(-1);
  g1(25,12)=1;
  g1(26,7)=(-1);
  g1(26,10)=(-1);
  g1(26,13)=1;
  g1(27,11)=1;
  g1(27,20)=(-1);
  g1(27,27)=(-1);
  g1(28,35)=(-(1-params(2)));
  g1(29,17)=(-1);
  g1(29,28)=1;
  g1(30,17)=(-1);
  g1(30,32)=1;
  g1(31,17)=(-1);
  g1(31,31)=1;
  g1(32,4)=(-1);
  g1(32,29)=1;
  g1(33,1)=(-1);
  g1(33,30)=1;
  g1(34,17)=(-1);
  g1(34,33)=1;
  g1(35,35)=(-1);
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],35,1225);
end
end
